[![Travis](https://travis-ci.com/tdegeus/GooseMPL.svg?branch=master)](https://travis-ci.com/tdegeus/GooseMPL)

[![Build status](https://ci.appveyor.com/api/projects/status/q6ty6h7sb9mu9jqx/branch/master?svg=true)](https://ci.appveyor.com/project/tdegeus/goosempl/branch/master)

[![Documentation Status](https://readthedocs.org/projects/goosempl/badge/?version=latest)](http://goosempl.readthedocs.io/en/latest/?badge=latest)

# GooseMPL

GooseMPL provides a style and several style extensions for matplotlib, 
some custom functions that extend matplotlib, 
and several examples to make professional plot using matplotlib. 

Documentation: [goosempl.readthedocs.io](https://goosempl.readthedocs.io)

# Disclaimer

This library is free to use under the [MIT license](LICENSE). 
Any additions are very much appreciated, in terms of suggested functionality, 
code, documentation, testimonials, word of mouth advertisement, .... 
Bug reports or feature requests can be filed on 
[GitHub](https://github.com/tdegeus/GooseMPL). 
As always, the code comes with no guarantee. 
None of the developers can be held responsible for possible mistakes.

Download: 
[.zip file](https://github.com/tdegeus/GooseMPL/zipball/master) | 
[.tar.gz file](https://github.com/tdegeus/GooseMPL/tarball/master).

(c - [MIT](LICENSE)) T.W.J. de Geus (Tom) | 
tom@geus.me | www.geus.me | 
[github.com/tdegeus/GooseMPL](https://github.com/tdegeus/GooseMPL)
